# AnalysisResultResponseResultPythoninterpreters

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**link** | **str** | A dereferenced symlink (if any) to the Python interpreter |
**path** | **str** | A path to the Python interpreter executable |
**version** | **str** | Python interpreter version |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

